@@ -27,6 +27,8 @@ class DayBetterClient:
         self.base_url = base_url
         self._session: Optional[aiohttp.ClientSession] = None
         self._auth_valid = True
+        self._devices: List[Dict[str, Any]] = []
+        self._pids: Dict[str, Any] = {}
     
     async def __aenter__(self):
         """Async context manager entry."""
@@ -330,6 +332,87 @@ class DayBetterClient:
         """Check if the API client is authenticated."""
         return self._auth_valid
     
+    def filter_sensor_devices(
+        self,
+        devices: List[Dict[str, Any]],
+        pids: Dict[str, Any],
+    ) -> List[Dict[str, Any]]:
+        """Filter devices to only include sensors based on PID.
+        
+        Args:
+            devices: List of all devices
+            pids: Dictionary containing device type PIDs
+            
+        Returns:
+            List of sensor devices only
+        """
+        sensor_pids_str = pids.get("sensor", "")
+        if not sensor_pids_str:
+            return []
+
+        sensor_pids = {pid.strip() for pid in sensor_pids_str.split(",")}
+
+        return [
+            device
+            for device in devices
+            if device.get("deviceMoldPid", "") in sensor_pids
+        ]
+    
+    def merge_device_status(
+        self,
+        devices: List[Dict[str, Any]],
+        statuses: List[Dict[str, Any]],
+    ) -> List[Dict[str, Any]]:
+        """Merge device info with status info.
+        
+        Args:
+            devices: List of device info dictionaries
+            statuses: List of device status dictionaries
+            
+        Returns:
+            List of merged device dictionaries
+        """
+        status_dict = {status.get("deviceName"): status for status in statuses}
+
+        merged = []
+        for device in devices:
+            device_name = device.get("deviceName")
+            merged_device = device.copy()
+
+            if device_name in status_dict:
+                merged_device.update(status_dict[device_name])
+
+            merged.append(merged_device)
+
+        return merged
+    
+    async def fetch_sensor_data(self) -> List[Dict[str, Any]]:
+        """Fetch and process sensor data in one call.
+        
+        This method fetches device statuses, devices list, and PIDs,
+        filters for sensor devices, and merges the data.
+        
+        Returns:
+            List of sensor devices with merged status data
+            
+        Raises:
+            AuthenticationError: If authentication fails
+            APIError: If API request fails
+        """
+        # Fetch current statuses
+        statuses = await self.fetch_device_statuses()
+        
+        # Fetch devices and PIDs if not cached
+        if not self._devices or not self._pids:
+            self._devices = await self.fetch_devices()
+            self._pids = await self.fetch_pids()
+        
+        # Filter to sensor devices only
+        sensor_devices = self.filter_sensor_devices(self._devices, self._pids)
+        
+        # Merge with current status
+        return self.merge_device_status(sensor_devices, statuses)
+    
     async def close(self):
         """Close the client session."""
         if self._session:
